@@ -1,9 +1,3 @@
-"""
-This file demonstrates writing tests using the unittest module. These will pass
-when you run "manage.py test".
-
-Replace this with more appropriate tests for your application.
-"""
 from email.mime.base import MIMEBase
 
 from django.test import TestCase
@@ -165,6 +159,7 @@ def mail_advanced(mail_to=default_to, mail_cc=None, mail_bcc=None,
 
 
 class Simple_Email(TestCase):
+    fixtures = ['initial_data.json']
 
     def setUp(self):
         mcfeely_backend = 'mcfeely.backend.DbBackend'
@@ -240,6 +235,18 @@ class Simple_Email(TestCase):
         self.assertEqual(len(mail.outbox), 1)
         self.assertEqual(results, 1)
 
+    def test_queue_name_mail(self):
+        """
+            Tests email sending with just a queue name and not a object
+        """
+        subject, results = mcfeely_send_mail(queue='Test_Queue')
+        call_command('send_queue', 'Test_Queue')
+
+        self.assertEqual(Email.objects.filter(
+            subject=subject, queue=self.queue).count(), 1)
+        self.assertEqual(len(mail.outbox), 1)
+        self.assertEqual(results, 1)
+
     def test_mail_admins(self):
         """
             Tests the mcfeely mail_admins() function
@@ -273,6 +280,7 @@ class Simple_Email(TestCase):
 
 
 class Advanced_Email(TestCase):
+    fixtures = ['initial_data.json']
 
     def setUp(self):
         mcfeely_backend = 'mcfeely.backend.DbBackend'
@@ -287,7 +295,7 @@ class Advanced_Email(TestCase):
     def test_attachment(self):
         """
             Simple mail attachment
-        """            
+        """
         subject, results = mail_attachment(queue=self.queue)
         call_command('send_queue', 'Test_Queue')
 
@@ -322,7 +330,7 @@ class Advanced_Email(TestCase):
         self.assertEqual(len(mail.outbox[0].alternatives), 1)
 
     def test_advanced_mail(self):
-        """ 
+        """
             Test advanced mail sending with extra headers
         """
         subject = mail_advanced(
@@ -344,6 +352,7 @@ class Advanced_Email(TestCase):
 
 
 class Unsubscribe_Email(TestCase):
+    fixtures = ['initial_data.json']
 
     def setUp(self):
         mcfeely_backend = 'mcfeely.backend.DbBackend'
